export default {
    "index": 33,
    "lineNumber": 1,
    "column": 34,
    "message": "Unexpected token await"
};